@@ -197,6 +197,7 @@ class HistoricalWebsocket:
                                       'bid_qty': int(j[5]),
                                       'ask': float(j[6]),
                                       'ask_qty': int(j[7])})
+                    # Even here catch missing bid ask
                 continue
             except IndexError:
                 # Missing bid-ask data
@@ -206,7 +207,7 @@ class HistoricalWebsocket:
 
 
 class TD:
-    def __init__(self, login_id, password, url='push.truedata.in', live_port=8082, historical_port=8092, fyers_token=None, *args):
+    def __init__(self, login_id, password, broker_token=None, url='push.truedata.in', live_port=8082, historical_port=8092, *args):
         self.live_websocket = None
         self.historical_websocket = None
         self.login_id = login_id
@@ -218,7 +219,7 @@ class TD:
             self.connect_historical = False
         else:
             self.connect_historical = True
-        self.fyers_token = fyers_token
+        self.broker_token = broker_token
         self.hist_data = {}
         self.live_data = {}
         self.symbol_mkt_id_map = {}
@@ -227,10 +228,10 @@ class TD:
         self.connect()
 
     def connect(self):
-        fyers_append = ''
-        if self.fyers_token is not None:
-            fyers_append = f'&brokertoken={self.fyers_token}'
-        self.live_websocket = LiveClient(self, f"wss://{self.url}:{self.live_port}?user={self.login_id}&password={self.password}{fyers_append}")
+        broker_append = ''
+        if self.broker_token is not None:
+            broker_append = f'&brokertoken={self.broker_token}'
+        self.live_websocket = LiveClient(self, f"wss://{self.url}:{self.live_port}?user={self.login_id}&password={self.password}{broker_append}")
         t = Thread(target=self.connect_thread, args=())
         t.start()
         if self.connect_historical:
