@@ -6,11 +6,13 @@ import pandas as pd
 from datetime import datetime
 from dateutil.relativedelta import relativedelta
 
-from colorama import Style, Fore
+from colorama import Style, Fore, init
 
 DEFAULT_LIVE_PORT = 8082
 DEFAULT_HIST_PORT = 8092
 
+init()
+
 
 def run_all_tests(username, password, live_port=None, historical_port=None, symbols_to_test=None):
     if live_port is None:
@@ -55,42 +57,52 @@ def run_historical_tests(td_app_ip, symbols):
     tick_hist_data_3 = td_app_ip.get_historic_data(f'{symbol}', bar_size='tick', start_time=test_time-relativedelta(days=3))
 
     print(f'{Style.BRIGHT}{Fore.BLUE}------------- HIST BAR DATA TEST RESULTS -------------{Style.RESET_ALL}')
+    print()
     print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 1...\n"
           f"\tCommand used -> hist_data_1 = td_app.get_historic_data('{symbol}')\n"
           f"\tLENGTH OF RESULT = {len(hist_data_1)}{Style.RESET_ALL}")
     for hist_point in hist_data_1[-20:]:
         print(hist_point)
+    print()
     print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 2...\n"
           f"\tCommand used -> hist_data_2 = td_app.get_historic_data('{symbol}', duration='3 D')\n"
           f"\tLENGTH OF RESULT = {len(hist_data_2)}{Style.RESET_ALL}")
     for hist_point in hist_data_2[-20:]:
         print(hist_point)
+    print()
     print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 3...\n"
           f"\tCommand used -> hist_data_3 = td_app.get_historic_data('{symbol}', duration='3 D', bar_size='15 mins')\n"
           f"\tLENGTH OF RESULT = {len(hist_data_3)}{Style.RESET_ALL}")
     for hist_point in hist_data_3[-20:]:
         print(hist_point)
+    print()
     print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 4...)\n"
           f"\tCommand used -> hist_data_4 = td_app.get_historic_data('{symbol}', bar_size='30 mins')\n"
           f"\tLENGTH OF RESULT = {len(hist_data_4)}{Style.RESET_ALL}")
     for hist_point in hist_data_4[-20:]:
         print(hist_point)
+    print()
     print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 5...\n"
           f"\tCommand used -> hist_data_5 = td_app.get_historic_data('{symbol}', bar_size='30 mins', start_time={test_time - relativedelta(days=3)})\n"
           f"\tLENGTH OF RESULT = {len(hist_data_5)}{Style.RESET_ALL}")
     for hist_point in hist_data_5[-20:]:
         print(hist_point)
+    print()
+    print()
     print(f'{Style.BRIGHT}{Fore.BLUE}------------- HIST TICK DATA TEST RESULTS -------------{Style.RESET_ALL}')
+    print()
     print(f"{Style.BRIGHT}{Fore.BLUE}TICKDATA 1...\n"
           f"\tCommand used -> tick_data_1 = td_app.get_historic_data('{symbol}', bar_size='tick')\n"
           f"\tLENGTH OF RESULT = {len(tick_hist_data_1)}{Style.RESET_ALL}")
     for hist_point in tick_hist_data_1[-20:]:
         print(hist_point)
+    print()
     print(f"{Style.BRIGHT}{Fore.BLUE}TICKDATA 2...\n"
           f"\tCommand used -> tick_data_2 = td_app.get_historic_data('{symbol}', bar_size='tick', duration='3 D')\n"
           f"\tLENGTH OF RESULT = {len(tick_hist_data_2)}{Style.RESET_ALL}")
     for hist_point in tick_hist_data_2[-20:]:
         print(hist_point)
+    print()
     print(f"{Style.BRIGHT}{Fore.BLUE}TICKDATA 3...\n"
           f"\tCommand used -> tick_data_3 = td_app.get_historic_data('{symbol}', bar_size='tick', start_time={test_time - relativedelta(days=3)})\n"
           f"\tLENGTH OF RESULT = {len(tick_hist_data_3)}{Style.RESET_ALL}")
